@@ -26,6 +26,7 @@ class LambdaFunction(Resource):
         "FileSystemConfigs": PropertyType(False, list_of(is_type(dict))),
         "CodeSigningConfigArn": PropertyType(False, is_str()),
         "ImageConfig": PropertyType(False, is_type(dict)),
+        "Architectures": PropertyType(False, list_of(one_of(is_str(), is_type(dict)))),
     }
 
     runtime_attrs = {"name": lambda self: ref(self.logical_id), "arn": lambda self: fnGetAtt(self.logical_id, "Arn")}
@@ -113,6 +114,7 @@ class LambdaLayerVersion(Resource):
         "Content": PropertyType(True, is_type(dict)),
         "Description": PropertyType(False, is_str()),
         "LayerName": PropertyType(False, is_str()),
+        "CompatibleArchitectures": PropertyType(False, list_of(one_of(is_str(), is_type(dict)))),
         "CompatibleRuntimes": PropertyType(False, list_of(one_of(is_str(), is_type(dict)))),
         "LicenseInfo": PropertyType(False, is_str()),
     }
